@@ -10,7 +10,7 @@ from . import core
 
 from .core.constants import DEFAULT, DEBUG, SILENT, RETRES, HIGHLIGHT, NO_COLOR, REVERSE_POW_XOR
 from .core.cache import undefined
-from .core.highlight import HLFMT_HTML, HLFMT_ANSI, HLFMT_BBCODE, pys_highlight
+from .core.highlight import HLFMT_HTML, HLFMT_ANSI, HLFMT_BBCODE, pys_highlight, PygmentsPyScriptLexer
 from .core.runner import pys_exec, pys_eval, pys_require, pys_shell
 from .core.version import version_info, __version__, __date__
 
@@ -32,5 +32,6 @@ __all__ = (
     'pys_exec',
     'pys_eval',
     'pys_require',
-    'pys_shell'
+    'pys_shell',
+    'PygmentsPyScriptLexer'
 )
\ No newline at end of file
