@@ -1,5 +1,5 @@
-from .constants import TOKENS, KEYWORDS
-from .mapping import PARENTHESISES_MAP
+from .constants import TOKENS, KEYWORDS, CONSTANT_KEYWORDS
+from .mapping import BRACKETS_MAP
 from .nodes import *
 
 is_expression = frozenset([
@@ -33,19 +33,15 @@ is_incremental = frozenset([
 ]).__contains__
 
 is_blacklist_python_builtins = frozenset([
-    'IndentationError', 'TabError', 'compile', 'copyright', 'credits', 'dir', 'eval', 'exec', 'help', 'globals',
-    'license', 'locals', 'vars'
+    'IndentationError', 'TabError', 'breakpoint', 'compile', 'copyright', 'credits', 'dir', 'eval', 'exec', 'help',
+    'globals', 'license', 'locals', 'vars'
 ]).__contains__
 
-is_left_parenthesis = frozenset(PARENTHESISES_MAP.keys()).__contains__
-is_right_parenthesis = frozenset(PARENTHESISES_MAP.values()).__contains__
-is_parenthesis = frozenset(PARENTHESISES_MAP.keys() | PARENTHESISES_MAP.values()).__contains__
+is_left_bracket = frozenset(BRACKETS_MAP.keys()).__contains__
+is_right_bracket = frozenset(BRACKETS_MAP.values()).__contains__
+is_bracket = frozenset(BRACKETS_MAP.keys() | BRACKETS_MAP.values()).__contains__
 
-is_constant_keywords = frozenset([
-    KEYWORDS['__debug__'], KEYWORDS['of'], KEYWORDS['in'], KEYWORDS['is'], KEYWORDS['and'], KEYWORDS['or'],
-    KEYWORDS['not'], KEYWORDS['False'], KEYWORDS['None'], KEYWORDS['True'], KEYWORDS['class'], KEYWORDS['false'],
-    KEYWORDS['func'], KEYWORDS['function'], KEYWORDS['global'], KEYWORDS['none'], KEYWORDS['true']
-]).__contains__
+is_constant_keywords = frozenset(CONSTANT_KEYWORDS).__contains__
 
 is_private_attribute = lambda name : name.startswith('_')
 is_public_attribute = lambda name : not name.startswith('_')
\ No newline at end of file
